template

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 10, 2026 License: MIT Imports: 5 Imported by: 0

README

Arvancloud module for Caddy

This package contains a DNS provider module for Caddy. It can be used to manage DNS records with Arvancloud accounts.

Caddy module name

dns.providers.arvancloud

Config examples

To use this module for the ACME DNS challenge, configure the ACME issuer in your Caddy JSON like so:

{
	"module": "acme",
	"challenges": {
		"dns": {
			"provider": {
				"name": "arvancloud",
				"api_key": "your_Arvancloud_api_key"
			}
		}
	}
}

or with the Caddyfile:

# globally
{
	acme_dns arvancloud your_Arvancloud_api_key
}
# one site
tls {
	dns arvancloud your_Arvancloud_api_key
}

Caveats

Arvancloud doesn't currently allow more than 1 IP address for a single A record on the free plan. this might change in the future but for now that means the API will return an error in this case.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Provider

type Provider struct{ *arvancloud.Provider }

Provider lets Caddy read and manipulate DNS records hosted by this DNS provider.

func (Provider) CaddyModule

func (Provider) CaddyModule() caddy.ModuleInfo

CaddyModule returns the Caddy module information.

func (*Provider) Provision

func (p *Provider) Provision(ctx caddy.Context) error

Provision sets up the module. Implements caddy.Provisioner.

func (*Provider) UnmarshalCaddyfile

func (p *Provider) UnmarshalCaddyfile(d *caddyfile.Dispenser) error

UnmarshalCaddyfile sets up the DNS provider from Caddyfile tokens. Syntax:

Single API Token

arvancloud <api_key>      // Domain read access and domain DNS write for all domains

Single API Token, alternative syntax

arvancloud {
  api_key <api_key>     // Domain read access and dmain DNS write for all domains
}

Jump to